# Test

## Living Standard, 1 January 1970

Version History:
  http://example.com/foo
  foo bold bar more bold baz
Bar:
  link to § 1 Introduction bold bar more bold more bar
This version:
  http://example.com/url-this-spec-will-live-at
Bar2:
  link to § 1 Introduction bold bar more bold more bar
Baz:
  some baz

COPYRIGHT GOES HERE

## Abstract

A short description of your spec, one or two sentences.

## 1. Introduction

Spec metadata should contain the following keys, in order: Version History, Bar, This version, Bar2, Baz.

"Bar" and "Bar2" should contain mixed text and several inline elements.